@@ -1,6 +1,6 @@
 package Map::Tube::Barcelona::Line::L3;
 
-$Map::Tube::Barcelona::Line::L3::VERSION = '0.08';
+$Map::Tube::Barcelona::Line::L3::VERSION = '0.09';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::Barcelona::Line::L3 - Barcelona Metro L3 Line stations.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =encoding utf8
 
@@ -61,13 +61,14 @@ Barcelona Metro L3 Line stations.
 
 =item * The staion "Vall d'Hebro" is also part L4 Line.
 
-=item * The station "Trinitat Nova" is also part of L4 Line and L11 Line.
+=item * The station "Trinitat Nova" is also part of L4 Line
+        | L<L11 Line|Map::Tube::Barcelona::Line::L11>.
 
-=item * The station "Diagonal" is also part of L5 Line and L6 Line.
+=item * The station "Diagonal" is also part of L5 Line | L6 Line.
 
-=item * The station "Passeig de Gràcia" is also part of L2 Line and L4 Line.
+=item * The station "Passeig de Gràcia" is also part of L2 Line | L4 Line.
 
-=item * The station "Catalunya" is also part of L1 Line and L7 Line.
+=item * The station "Catalunya" is also part of L1 Line | L7 Line.
 
 =back
 
